@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Cheers!" : "শুভেচ্ছা!",
     "Calendar" : "দিনপঞ্জী",
-    "Personal" : "ব্যক্তিগত",
     "Today" : "আজ",
     "Day" : "দিবস",
     "Week" : "সপ্তাহ",
@@ -38,19 +37,17 @@ OC.L10N.register(
     "Notification" : "নোটিফিকেশন ",
     "Email" : "ইমেইল",
     "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
+    "Done" : "শেষ হলো",
     "Unknown" : "অজানা",
-    "Send email" : "ইমেইল পাঠান ",
+    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
     "Repeat" : "পূনঃসংঘটন",
     "never" : "কখনোই নয়",
-    "More" : "বেশী",
     "Subscribe" : "গ্রাহক হোন",
+    "Personal" : "ব্যক্তিগত",
     "Details" : "বিসতারিত",
-    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
     "Close" : "বন্ধ",
     "Daily" : "দৈনিক",
     "Weekly" : "সাপ্তাহিক",
-    "Other" : "অন্যান্য",
-    "Mail" : "মেইল",
-    "Birthday" : "জন্মদিন"
+    "Other" : "অন্যান্য"
 },
 "nplurals=2; plural=(n != 1);");
