@@ -8,7 +8,6 @@ OC.L10N.register(
     "Cheers!" : "Tudelu!",
     "Calendar" : "Kalender",
     "Prepare for %s" : "Klargjer for %s",
-    "Personal" : "Personleg",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Veke",
@@ -47,16 +46,15 @@ OC.L10N.register(
     "Delete file" : "Slett fil",
     "Unknown" : "Ukjend",
     "Tentative" : "Førebels",
-    "Send email" : "Send e-post",
+    "Attendees" : "Deltakarar",
     "Repeat" : "Gjenta",
     "never" : "aldri",
     "after" : "etter",
     "last" : "siste",
     "Room type" : "Romtype",
-    "More" : "Meir",
     "Global" : "Global",
+    "Personal" : "Personleg",
     "Details" : "Detaljar",
-    "Attendees" : "Deltakarar",
     "Close" : "Lukk",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
@@ -66,10 +64,6 @@ OC.L10N.register(
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
     "Status" : "Status",
-    "Confirmed" : "Stadfesta",
-    "Money" : "Pengar",
-    "Talk" : "Prat",
-    "Mail" : "Post",
-    "Birthday" : "Bursdag"
+    "Confirmed" : "Stadfesta"
 },
 "nplurals=2; plural=(n != 1);");
