@@ -2,7 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "يىلنامە",
-    "Personal" : "شەخسىي",
     "Today" : "بۈگۈن",
     "Week" : "ھەپتە",
     "Month" : "ئاي",
@@ -30,12 +29,11 @@ OC.L10N.register(
     "Update" : "يېڭىلا",
     "Your email address" : "تورخەت ئادرېسىڭىز",
     "Email" : "تورخەت",
+    "Attendees" : "قاتناشقۇچىلار",
     "Repeat" : "قايتىلا",
     "never" : "ھەرگىز",
-    "More" : "تېخىمۇ كۆپ",
-    "Attendees" : "قاتناشقۇچىلار",
+    "Personal" : "شەخسىي",
     "Close" : "ياپ",
-    "Other" : "باشقا",
-    "Birthday" : "تۇغۇلغان كۈن"
+    "Other" : "باشقا"
 },
 "nplurals=2; plural=(n != 1);");
